sed_trp_shallow_flow Package
============================

:mod:`sed_trp_shallow_flow` Package
-----------------------------------

.. automodule:: landlab.components.sed_trp_shallow_flow
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`transport_sed_in_shallow_flow` Module
-------------------------------------------

.. automodule:: landlab.components.sed_trp_shallow_flow.transport_sed_in_shallow_flow
    :members:
    :undoc-members:
    :show-inheritance:

